@@ -3,7 +3,7 @@ package builtins;
 use 5.036;
 use warnings;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 sub import {
     warnings->unimport('experimental::builtin');
@@ -15,6 +15,7 @@ sub import {
             created_as_string created_as_number
             ceil floor
             trim
+            indexed
           >
     );
 }
@@ -53,7 +54,7 @@ This document describes C<builtins> version 0.000001
 
 =head1 DESCRIPTION
 
-Perl 5.36 introduced 14 new built-in functions to the core.
+Perl 5.36 introduced numerous new built-in functions to the core.
 Unfortunately, for backwards compatibility, none of them are
 automatically available. And all of them are still experimental.
 
@@ -64,7 +65,7 @@ Which means, if you want them all, you have to preface your code with:
         ceil    floor     trim
         true    false     is_bool
         weaken  unweaken  is_weak
-        blessed refaddr   reftype
+        blessed refaddr   reftype   indexed
         created_as_string created_as_number
     );
 
